@@ -1,4 +1,5 @@
 use crate::context::Context;
+use crate::error::new_application_error;
 use crate::error::new_not_found_error;
 use crate::error::Error;
 use crate::internal_context::InternalContext;
@@ -7,6 +8,7 @@ use crate::payment::Initiator;
 use crate::payment::Payment;
 use crate::payment::PaymentProcessor;
 
+use super::LookupKey;
 use super::Order;
 use super::OrderState;
 
@@ -61,6 +63,48 @@ pub async fn cancel_handler<C: Context + Send>(
     Ok(od)
 }
 
+pub async fn reconcile_handler<C: Context + Send>(
+    ctx: &mut C,
+    lookup_key: LookupKey,
+) -> Result<(), Error> {
+    let maybe_order = match &lookup_key {
+        LookupKey::CheckoutId(checkout_id) => get_order_by_checkout_id(ctx, checkout_id).await?,
+        LookupKey::OrderId(order_id) => ctx.get_order_for_update(order_id).await?,
+    };
+
+    if maybe_order.is_none() {
+        // this isn't supposed to happen
+        return Err(new_not_found_error(
+            "the requested order could not be found",
+        ));
+    }
+
+    let mut od = maybe_order.unwrap();
+
+    od.reconcile(ctx).await
+}
+
+async fn get_order_by_checkout_id<C: Context + Send>(
+    ctx: &mut C,
+    checkout_id: &str,
+) -> Result<Option<Order>, Error> {
+    let maybe_checkout = ctx.get_checkout_for_update(checkout_id).await?;
+    if maybe_checkout.is_none() {
+        return Err(new_not_found_error(
+            "the associated checkout could not be found",
+        ));
+    }
+
+    let checkout = maybe_checkout.unwrap();
+    if checkout.order_id.is_none() {
+        return Err(new_application_error(
+            "INVALID_ASSOCIATED_CHECKOUT",
+            "there is no order associated with the checkout",
+        ));
+    }
+    ctx.get_order_for_update(&checkout.order_id.unwrap()).await
+}
+
 async fn get_order_payment_for_update<C: Context + Send>(
     ctx: &mut C,
     order_id: &str,
