@@ -70,7 +70,7 @@ pub trait OrderStore {
 
 #[async_trait]
 pub trait OrderEvents {
-    async fn on_pending_payment(&mut self, _order: &Order) -> Result<(), Error> {
+    async fn on_payment_in_progress(&mut self, _order: &Order) -> Result<(), Error> {
         Ok(())
     }
 
@@ -280,6 +280,23 @@ impl Order {
         self.ensure_cancelled_state(internal_ctx).await?;
         ctx.update_order(self).await
     }
+
+    pub async fn reconcile<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
+        if self.state_reconciled == true {
+            return Ok(());
+        }
+
+        match self.state {
+            OrderState::PaymentInProgress => ctx.on_payment_in_progress(self).await?,
+            OrderState::PendingConfirmation => ctx.on_pending_confirmation(self).await?,
+            OrderState::Confirmed => ctx.on_confirmed(self).await?,
+            OrderState::Fulfilled => ctx.on_fulfilled(self).await?,
+            OrderState::Cancelled => ctx.on_cancelled(self).await?,
+        }
+
+        self.state_reconciled = true;
+        ctx.update_order(self).await
+    }
 }
 
 async fn publish_state_change_event(
