@@ -80,8 +80,8 @@ pub async fn process_handler<C: Context + Send>(
 ) -> Result<(), Error> {
     let maybe_payment = ctx.get_payment_for_update(id).await?;
     if maybe_payment.is_none() {
-        // this isn't supposed to happen. maybe log the error and move on
-        return Ok(());
+        // this isn't supposed to happen.
+        return Err(new_not_found_error("the requested payment could not be found"));
     }
 
     let mut payment = maybe_payment.unwrap();
@@ -90,8 +90,8 @@ pub async fn process_handler<C: Context + Send>(
         InitiatorId::Checkout(co_id) => {
             let maybe_co = ctx.get_checkout_for_update(co_id).await?;
             if maybe_co.is_none() {
-                // this isn't supposed to happen. maybe log the error and move on
-                return Ok(());
+                // this isn't supposed to happen.
+                return Err(new_not_found_error("the associated checkout could not be found"));
             }
 
             let mut checkout = maybe_co.unwrap();
@@ -106,8 +106,8 @@ pub async fn process_handler<C: Context + Send>(
         InitiatorId::Order(od_id) => {
             let maybe_od = ctx.get_order_for_update(od_id).await?;
             if maybe_od.is_none() {
-                // this isn't supposed to happen. maybe log the error and move on
-                return Ok(());
+                // this isn't supposed to happen.
+                return Err(new_not_found_error("the associated order could not be found"));
             }
 
             let mut order = maybe_od.unwrap();
