@@ -42,9 +42,9 @@ pub enum Initiator<'a> {
 
 #[async_trait]
 pub trait PaymentProcessor {
-    type ProcessArgs: Sync;
-    type PrivateData: Sync;
-    type PublicData: Sync;
+    type ProcessArgs: Sync + Send;
+    type PrivateData: Sync + Send;
+    type PublicData: Sync + Send;
 
     async fn initiate_payment(
         &mut self,
